<?php
/**
 * Pocket Project
 * 
 * @copyright 2006 Power-Station co., Ltd, ALL Rights Reserved,
 */

/**
 *  Actionクラス
 *
 *  @author     Shogo Minami
 *  @access     public
 *  @package    PocketBlog
 */
class Pocket_Blog_Action extends Pocket_Action
{
    /**
     *  コンストラクタ
     *
     *  @access public
     */
    function Pocket_Blog_Action()
    {
        // 親クラスのコンストラクタ
        parent::Pocket_Action();
        // ユーザIDを初期化（未設定の場合は、初期登録ユーザのIDを設定）
        if (!isset($_SESSION['user_id'])) {$_SESSION['user_id'] = db_get_user4first_user_id();}
    }

    /**
     *  サイドメニュー情報をテンプレート変数に設定
     *
     *  @access public
     */
    function assignSideMenuInfo()
    {
        // セッション情報の取得
        $user_id = $_SESSION['user_id'];
        $year    = $_SESSION['year'];
        $month   = $_SESSION['month'];

        // カレンダーリストの設定
        $this->smarty->assign('calendar_list', pocket_getCalendarList($year, $month, db_get_post_date4year_month($year, $month)));
        // 最新の記事情報の取得、設定
        $this->smarty->assign('latest_post_list', db_get_posts4latest_post_list(1, NEWS_SIZE));
        // 最新のコメント情報の取得、設定
        $this->smarty->assign('latest_comment_list', db_get_post_comments4latest_comment_list(1, NEWS_SIZE));
        // 最新のトラックバック情報の取得、設定
        $this->smarty->assign('latest_trackback_list', db_get_trackbacks4latest_trackback_list(1, NEWS_SIZE));
        // カテゴリ情報の取得、設定
        $this->smarty->assign('category_list', db_get_categories4category_list());
        // 過去の記事一覧情報の取得、設定
        $this->smarty->assign('archive_list', db_get_posts4archive_list());
        // リンク情報の取得、設定
        $this->smarty->assign('link_list', db_get_links4link_list());
        // ユーザ情報の取得、設定
        $this->smarty->assign('user_profile', db_get_user($user_id));
        // 非公開の記事件数の取得、設定
        $this->smarty->assign('closed_post_count', db_get_posts_count4closed());
        // 未承認のコメント件数の取得、設定
        $this->smarty->assign('unapproved_comment_count', db_get_post_comments_count4unapproved());
        // 未承認のトラックバック件数の取得、設定
        $this->smarty->assign('unapproved_trackback_count', db_get_trackbacks_count4unapproved());

        // 本日のアクセス件数の取得、設定
        $count = db_get_accessCount4day(0);
        $this->smarty->assign('access_count_today', $count);
        $this->smarty->assign('access_count_today_assoc', pocket_getCountAssoc($count, 6));
        // 昨日のアクセス件数の取得、設定
        $count = db_get_accessCount4day(-1);
        $this->smarty->assign('access_count_yesterday', $count);
        $this->smarty->assign('access_count_yesterday_assoc', pocket_getCountAssoc($count, 6));
        // 累計のアクセス件数の取得、設定
        $count = db_get_accessCount4total();
        $this->smarty->assign('access_count_total', $count);
        $this->smarty->assign('access_count_total_assoc', pocket_getCountAssoc($count, 6));

        // バナー情報（ランダム）の取得、設定
        $this->smarty->assign('banner_list', db_get_banner4random(1, BANNER_SIZE));
    }

    /**
     *  年月情報をSESSION変数に設定
     *
     *  @access public
     *  @param  integer $year               年
     *  @param  integer $month              月
     */
    function setYearMonthInfo2Session(&$year, &$month)
    {
        // 年月情報のチェック
        if (!isset($year) || !isset($month)) {
            // システム年月を設定
            $today = getdate();
            $year = $today['year'];
            $month = $today['mon'];
        }

        // 年月情報の設定
        $_SESSION['year'] = $year;
        $_SESSION['month'] = $month;
    }

    /**
     *  コメントスパムの判定
     *
     *  @access public
     *  @param  string  $comment            コメント
     */
    function isCommentSpam($comment = '')
    {
        // 半角英数記号のみのかチェック
        if (preg_match('/^[!-~]+$/', $comment))
        {
            return true;
        }
        // URLの数が5つ以上かチェック
        if (function_exists('mb_substr_count'))
        {
            if (mb_substr_count($comment, 'http://') > 4)
            {
                return true;
            }
        }
        return false;
    }

    /**
     *  認証アクションフラグ
     *
     *  @access public
     *  @return boolean true,false
     */
    function isSecure()
    {
        return false;
    }
}

?>
